#!/bin/bash
#
#       /etc/rc.d/init.d/Netshut
#
# chkconfig: 2345 80 20
# description: Netshut Listen on port 7006 waiting \
#   for a signal from Web/SNMP Card, if it gets the \
#   signal it execute a doshutdown scropt.
# processname: Netshut 
# Source function library.
. /etc/rc.d/init.d/functions
. /etc/sysconfig/network

[ ${NETWORKING} = "no" ] && exit 0

test -x /usr/local/Netshut/Netshut || exit 0
PATH=/usr/local/Netshut:$PATH

HOSTADDR=0.0.0.0
NODE_PORT=5769
NODE_TIME=10

umstatus() {
        # Test syntax.
        if [ $# = 0 ] ; then
                echo "Usage: status {program}"
                return 1
        fi

        # First try "pidof"
        pid=`pidof $1`
        if [ "$pid" != "" ] ; then
                echo "$1 (pid $pid) is running..."
                return 0
        else
                pid=`ps ax | awk 'BEGIN { prog=ARGV[1]; ARGC=1 }
                           { if ((prog == $5) || (("(" prog ")") == $5) ||
                             (("[" prog "]") == $5) ||
                           ((prog ":") == $5)) { print $1 ; exit 0 } }' $1`
                if [ "$pid" != "" ] ; then
                        echo "$1 (pid $pid) is running..."
                        return 0
                fi
        fi

        # Next try "/var/run/*.pid" files
        if [ -f /var/run/$1.pid ] ; then
                pid=`head -1 /var/run/$1.pid`
                if [ "$pid" != "" ] ; then
                        echo "$1 dead but pid file exists"
                        return 1
                fi
        fi
        # See if /var/lock/subsys/$1 exists
        if [ -f /var/lock/subsys/$1 ]; then
                echo "$1 dead but subsys locked"
                return 2
        fi
        echo "$1 is stopped"
        return 3
}

case "$1" in
    start)
        echo -n "Starting Netshut services: "
	cd /usr/local/Netshut
        daemon Netshut $HOSTADDR -p:$NODE_PORT -t:$NODE_TIME
	echo
        touch /var/lock/subsys/Netshut
        ;;
    stop)
        echo -n "Shutting down Netshut services: "
        killproc Netshut
	echo
        rm -f /var/lock/subsys/Netshut
        ;;
    status)
	umstatus Netshut
        ;;
    restart)
        echo -n "Shutting down Netshut services: "
        killproc Netshut
	echo
        rm -f /var/lock/subsys/Netshut
        echo -n "Starting Netshut services: "
	cd /usr/local/Netshut
        daemon Netshut $HOSTADDR -p:$NODE_PORT -t:$NODE_TIME 
	echo
        touch /var/lock/subsys/Netshut
        ;;
    reload)
        echo -n "Shutting down Netshut services: "
        killproc Netshut
	echo
        rm -f /var/lock/subsys/Netshut

        echo -n "Starting Netshut services: "
	cd /usr/local/Netshut
        daemon Netshut $HOSTADDR -p:$NODE_PORT -t:$NODE_TIME 
	echo
        touch /var/lock/subsys/Netshut
        ;;
    *)
        echo "usage: Netshut { start | stop | status | reload | restart }"
        exit 1
        ;;
esac



